@@ -106,6 +106,9 @@ actions <- function(action_id = NULL,
                     tidy = TRUE,
                     ...) {
 
+  ## check connectivity
+  check_connectivity()
+
   ## check that arguments are character
   coll <- checkmate::makeAssertCollection()
   mapply(FUN = checkmate::assert_character,
@@ -199,8 +202,9 @@ actions <- function(action_id = NULL,
                     args,
                     file = NULL,
                     ...)
-    }
+  }
 
+  if(is.null(content)) return(content)
   ## return raw JSON
   if(!isTRUE(tidy)) return(content)
 
