@@ -77,6 +77,9 @@ assessment_units <- function(assessment_unit_identifer = NULL,
                              tidy = TRUE,
                              ...) {
 
+  ## check connectivity
+  check_connectivity()
+
   ## check that arguments are character
   coll <- checkmate::makeAssertCollection()
   mapply(FUN = checkmate::assert_character,
@@ -151,6 +154,8 @@ assessment_units <- function(assessment_unit_identifer = NULL,
                     ...)
   }
 
+  if(is.null(content)) return(content)
+
   if (!isTRUE(tidy)) {
     return(content)
   } else {
