@@ -46,6 +46,9 @@ plans <- function(huc,
                   tidy = TRUE,
                   ...) {
 
+  ## check connectivity
+  check_connectivity()
+
   ## check that arguments are character
   coll <- checkmate::makeAssertCollection()
   mapply(FUN = checkmate::assert_character,
@@ -108,6 +111,8 @@ plans <- function(huc,
                     ...)
   }
 
+  if(is.null(content)) return(content)
+
   if(!isTRUE(tidy)) { ## return raw data
     return(content)
   } else { ## return parsed data
