@@ -47,6 +47,9 @@ state_summary <- function(organization_id = NULL,
                           tidy = TRUE,
                           ...) {
 
+  ## check connectivity
+  check_connectivity()
+
   ## check that arguments are character
   coll <- checkmate::makeAssertCollection()
   mapply(FUN = checkmate::assert_character,
@@ -96,6 +99,9 @@ state_summary <- function(organization_id = NULL,
                     ...)
   }
 
+
+  if(is.null(content)) return(content)
+
   if(!isTRUE(tidy)) { ## return raw data
     return(content)
   } else {## return parsed data
