@@ -42,6 +42,9 @@ surveys <- function(organization_id = NULL,
                     tidy = TRUE,
                     ...) {
 
+  ## check connectivity
+  check_connectivity()
+
   ## check that arguments are character
   coll <- checkmate::makeAssertCollection()
   mapply(FUN = checkmate::assert_character,
@@ -99,6 +102,8 @@ surveys <- function(organization_id = NULL,
                     ...)
   }
 
+  if(is.null(content)) return(content)
+
   ## return raw JSON
   if(!isTRUE(tidy)) return(content)
   ## parse and tidy JSON
