@@ -59,21 +59,21 @@ x
 ## ----include=FALSE------------------------------------------------------------
 vcr::eject_cassette("domains_works")
 
-## ----hoard--------------------------------------------------------------------
-## set package option
-rATTAINS_options(cache_downloads = TRUE)
-
-x <- domain_values(domain_name = "UseName", context = "TCEQMAIN")
-
-## This returns the file path where the files are cached
-dv_cache$cache_path_get()
-
-## get a list of cached files
-dv_cache$list()
-
-## delete one file
-#dv_cache$delete(dv_cache$list()[[1]])
-
-## delete all files in the directory
-dv_cache$delete_all()
+## ----hoard, eval=FALSE--------------------------------------------------------
+#  ## set package option
+#  rATTAINS_options(cache_downloads = TRUE)
+#  
+#  x <- domain_values(domain_name = "UseName", context = "TCEQMAIN")
+#  
+#  ## This returns the file path where the files are cached
+#  dv_cache$cache_path_get()
+#  
+#  ## get a list of cached files
+#  dv_cache$list()
+#  
+#  ## delete one file
+#  #dv_cache$delete(dv_cache$list()[[1]])
+#  
+#  ## delete all files in the directory
+#  dv_cache$delete_all()
 
